@@ -124,6 +124,8 @@ class MLaunchTool(BaseCmdLineTool):
         # set up argument parsing in run, so that subsequent calls to run can call different sub-commands
         self.argparser = argparse.ArgumentParser()
         self.argparser.add_argument('--version', action='version', version="mtools version %s" % __version__)
+        self.argparser.add_argument('--no-progressbar', action='store_true', default=False, help='disables progress bar')
+
 
         self.argparser.description = 'script to launch MongoDB stand-alone servers, replica sets and shards.'
 
@@ -167,7 +169,7 @@ class MLaunchTool(BaseCmdLineTool):
 
         # authentication, users, roles
         self._default_auth_roles = ['dbAdminAnyDatabase', 'readWriteAnyDatabase', 'userAdminAnyDatabase', 'clusterAdmin']
-        init_parser.add_argument('--auth', action='store_true', default=False, help='enable authentication and create a key file and admin user (admin/mypassword)')
+        init_parser.add_argument('--auth', action='store_true', default=False, help='enable authentication and create a key file and admin user (default=user/password)')
         init_parser.add_argument('--username', action='store', type=str, default='user', help='username to add (requires --auth, default=user)')
         init_parser.add_argument('--password', action='store', type=str, default='password', help='password for given username (requires --auth, default=password)')
         init_parser.add_argument('--auth-db', action='store', type=str, default='admin', metavar='DB', help='database where user will be added (requires --auth, default=admin)')
@@ -917,6 +919,10 @@ class MLaunchTool(BaseCmdLineTool):
             argument was accepted, then it is accepted as well. Example ['--slowms', '1000'] both arguments
             would be accepted for a mongod.
         """
+
+        if self.args and self.args['binarypath']:
+            binary = os.path.join( self.args['binarypath'], binary)
+
         # get the help list of the binary
         ret = subprocess.Popen(['%s --help'%binary], stderr=subprocess.STDOUT, stdout=subprocess.PIPE, shell=True)
         out, err = ret.communicate()
