@@ -1,6 +1,7 @@
 from mtools.util import OrderedDict
 from mtools.util.hci import DateTimeBoundaries
 from datetime import datetime, timedelta, MINYEAR, MAXYEAR
+from dateutil.tz import tzutc
 from mtools.util.logevent import LogEvent
 
 from base_filter import BaseFilter
@@ -11,7 +12,7 @@ def custom_parse_dt(value):
 
 
 class DateTimeFilter(BaseFilter):
-    """ This filter has two parser arguments: --from and --to, both are 
+    """ This filter has two parser arguments: --from and --to, both are
         optional. All possible values for --from and --to can be described as:
 
         [DATE] [TIME] [OFFSET] in that order, separated by a space.
@@ -27,8 +28,8 @@ class DateTimeFilter(BaseFilter):
 
         [OFFSET] consists of [OPERATOR][VALUE][UNIT]   (no spaces in between)
 
-        [OPERATOR] can be + or - (note that - can only be used if the whole 
-            "[DATE] [TIME] [OFFSET]" is in quotation marks, otherwise it would 
+        [OPERATOR] can be + or - (note that - can only be used if the whole
+            "[DATE] [TIME] [OFFSET]" is in quotation marks, otherwise it would
             be confused with a separate parameter)
 
         [VALUE] can be any number
@@ -38,16 +39,16 @@ class DateTimeFilter(BaseFilter):
 
         The [OFFSET] is added/subtracted to/from the specified [DATE] [TIME].
 
-        For the --from parameter, the default is the same as 'start' 
-            (0001-01-01 00:00:00). If _only_ an [OFFSET] is given, it is 
+        For the --from parameter, the default is the same as 'start'
+            (0001-01-01 00:00:00). If _only_ an [OFFSET] is given, it is
             added to 'start' (which is not very useful).
 
-        For the --to parameter, the default is the same as 'end' 
-            (9999-31-12 23:59:59). If _only_ an [OFFSET] is given, however, 
+        For the --to parameter, the default is the same as 'end'
+            (9999-31-12 23:59:59). If _only_ an [OFFSET] is given, however,
             it is added to [FROM].
 
-        Examples:  
-            --from Sun 10:00 
+        Examples:
+            --from Sun 10:00
                 goes from last Sunday 10:00:00am to the end of the file
 
             --from Sep 29
@@ -59,12 +60,12 @@ class DateTimeFilter(BaseFilter):
             --from today --to +1h
                 goes from today's date 00:00:00 to today's date 01:00:00
 
-            --from 20:15 --to +3m  
+            --from 20:15 --to +3m
                 goes from today's date at 20:15:00 to today's date at 20:18:00
     """
 
     filterArgs = [
-       ('--from', {'action':'store',  'type':custom_parse_dt, 'nargs':'*', 'default':'start', 'help':'output starting at FROM', 'dest':'from'}), 
+       ('--from', {'action':'store',  'type':custom_parse_dt, 'nargs':'*', 'default':'start', 'help':'output starting at FROM', 'dest':'from'}),
        ('--to',   {'action':'store',  'type':custom_parse_dt, 'nargs':'*', 'default':'end',   'help':'output up to TO',         'dest':'to'})
     ]
 
@@ -72,13 +73,13 @@ class DateTimeFilter(BaseFilter):
     weekdays = ['Mon', 'Tue', 'Wed', 'Thu', 'Fri', 'Sat', 'Sun']
     months = ['Jan', 'Feb', 'Mar', 'Apr', 'May', 'Jun', 'Jul', 'Aug', 'Sep', 'Oct', 'Nov', 'Dec']
 
-    dtRegexes = OrderedDict([         
+    dtRegexes = OrderedDict([
         ('weekday', r'|'.join(weekdays)),                         # weekdays: see above
         ('date',    '('+ '|'.join(months) +')' + r'\s+\d{1,2}'),  # month + day:  Jan 5, Oct 13, Sep 03, ...
         ('word',    r'now|start|end|today'),
         ('time2',   r'\d{1,2}:\d{2,2}'),                          # 11:59, 1:13, 00:00, ...
         ('time3',   r'\d{1,2}:\d{2,2}:\d{2,2}'),                  # 11:59:00, 1:13:12, 00:00:59, ...
-        ('offset',  r'[\+-]\d+(' + '|'.join(timeunits) + ')'),    # offsets: +3min, -20s, +7days, ...                    
+        ('offset',  r'[\+-]\d+(' + '|'.join(timeunits) + ')'),    # offsets: +3min, -20s, +7days, ...
     ])
 
     def __init__(self, mlogfilter):
@@ -96,9 +97,9 @@ class DateTimeFilter(BaseFilter):
         if self.mlogfilter.is_stdin:
             # assume this year (we have no other info)
             now = datetime.now()
-            self.startDateTime = datetime(now.year, 1, 1)
-            self.endDateTime = datetime(MAXYEAR, 12, 31)
-        
+            self.startDateTime = datetime(now.year, 1, 1, tzinfo=tzutc())
+            self.endDateTime = datetime(MAXYEAR, 12, 31, tzinfo=tzutc())
+
         else:
             logfiles = self.mlogfilter.args['logfile']
             self.startDateTime = min([lf.start+timedelta(hours=self.mlogfilter.args['timezone'][i]) for i, lf in enumerate(logfiles)])
@@ -106,34 +107,52 @@ class DateTimeFilter(BaseFilter):
 
         # now parse for further changes to from and to datetimes
         dtbound = DateTimeBoundaries(self.startDateTime, self.endDateTime)
-        self.fromDateTime, self.toDateTime = dtbound(self.mlogfilter.args['from'] or None, 
+        self.fromDateTime, self.toDateTime = dtbound(self.mlogfilter.args['from'] or None,
                                                      self.mlogfilter.args['to'] or None)
 
         # define start_limit for mlogfilter's fast_forward method
         self.start_limit = self.fromDateTime
 
+        # for single logfile, get file seek position of `to` datetime
+        if len(self.mlogfilter.args['logfile']) == 1 and not self.mlogfilter.is_stdin:
+
+            if self.mlogfilter.args['to'] != "end":
+                # fast forward, get seek value, then reset file
+                logfile = self.mlogfilter.args['logfile'][0]
+                logfile.fast_forward(self.toDateTime)
+                self.seek_to = logfile.filehandle.tell()
+                logfile.filehandle.seek(0)
+            else:
+                self.seek_to = -1
+        else:
+            self.seek_to = False
+
 
     def accept(self, logevent):
-        dt = logevent.datetime
-
-        # if logevent has no datetime, accept if between --from and --to
-        if dt == None:
-            return self.fromReached
-
-        if self.fromDateTime <= dt <= self.toDateTime:
-            self.toReached = False
-            self.fromReached = True
+        if self.fromReached and self.seek_to:
+            if self.seek_to != -1:
+                self.toReached = self.mlogfilter.args['logfile'][0].filehandle.tell() >= self.seek_to
             return True
+        else:
+            # slow version has to check each datetime
+            dt = logevent.datetime
 
-        elif dt > self.toDateTime:
-            self.toReached = True
-            return False
+            # if logevent has no datetime, accept if between --from and --to
+            if dt == None:
+                return self.fromReached
+
+            if self.fromDateTime <= dt <= self.toDateTime:
+                self.toReached = False
+                self.fromReached = True
+                return True
+
+            elif dt > self.toDateTime:
+                self.toReached = True
+                return False
+
+            else:
+                return False
 
-        else: 
-            return False
 
-        
     def skipRemaining(self):
         return self.toReached
-
-
