@@ -82,7 +82,7 @@ class RangePlotType(BasePlotType):
 
         return artists
 
-    def print_line(self, event):
+    def clicked(self, event):
         group = event.artist._mt_group
         print num2date(event.artist._mt_left).strftime("%a %b %d %H:%M:%S"), '-', num2date(event.artist._mt_right).strftime("%a %b %d %H:%M:%S")
 
