@@ -5,7 +5,7 @@ from nose.tools import *
 from datetime import datetime
 from mtools.util.logfile import LogFile
 from mtools.util.logevent import LogEvent
-from dateutil.tz import tzutc
+from dateutil.tz import tzutc, tzoffset
 
 
 class TestUtilLogFile(object):
@@ -41,6 +41,15 @@ class TestUtilLogFile(object):
         assert logfile.end == datetime(2014, 01, 02, 23, 27, 11, 720000, tzutc())
 
 
+    def test_timezone(self):
+
+        logfile_path = os.path.join(os.path.dirname(mtools.__file__), 'test/logfiles/', 'mongod_26.log')
+        mongod_26 = open(logfile_path, 'r')
+
+        logfile = LogFile(mongod_26)
+        assert logfile.timezone == tzoffset(None, -14400)
+
+
     def test_rollover_detection(self):
         """ LogFile: test datetime_format and year_rollover properties """
 
